@@ -1,11 +1,13 @@
-from . import ToolRegistry, ToolInfoEncoder, HubReadmeHandler, QuayReadmeHandler, ToolInfo, Remotes
-from os.path import basename
 import argparse
-import sys
-import logging
 import asyncio
 import json
+import logging
+import sys
+from os.path import basename
 from typing import Dict
+from importlib import reload
+
+from . import ToolRegistry, ToolInfoEncoder, HubReadmeHandler, QuayReadmeHandler, ToolInfo, Remotes
 
 DEFAULT_IMAGE_FILTER_TAG = "latest"
 
@@ -54,10 +56,11 @@ class ANSIEscape:
 
 def print_single_tool_version_check(tool, show_tags: bool = False):
     # Provider name length
+    PROVIDER_UNDEFINED = "undefined"
     MAX_WN = 25
     MAX_WV = 40
     print(f"\n{' ':<{PRE_SPACE}}{ANSIEscape.GREEN}  {tool.get('name')}{ANSIEscape.END}")
-    # pre-space and text format
+    # pre-space and text formahttps://soundcharts.com/blog/music-streaming-rates-payoutst
     print(f"\n{' ':<{PRE_SPACE}}", end="")
     # Location
     underlined_loc = f"{ANSIEscape.UNDERLINE}Location{ANSIEscape.END}"
@@ -90,17 +93,20 @@ def print_single_tool_version_check(tool, show_tags: bool = False):
         print()
     # other
     if tool.get("versions").get("origin"):
+        provider = tool.get('versions').get('origin').get('details').get('provider') if tool.get('versions').get(
+            'origin').get('details').get('provider') else PROVIDER_UNDEFINED
         print(
             f"{' ':<{PRE_SPACE}}| Origin ("
-            f"{tool.get('versions').get('origin').get('details').get('provider') + ')':<{MAX_WN - 8}}",
+            f"{provider + ')':<{MAX_WN - 8}}",
             end="",
         )
         print(f"{tool.get('versions').get('origin').get('version'):<{MAX_WV}}")
 
     if tool.get("versions").get("other"):
         for other in tool.get("versions").get("other"):
+            provider = other.get('details').get('provider') if other.get('details') else PROVIDER_UNDEFINED
             print(
-                f"{' ':<{PRE_SPACE}}| {other.get('details').get('provider'):<{MAX_WN}}",
+                f"{' ':<{PRE_SPACE}}| {provider:<{MAX_WN}}",
                 end="",
             )
             print(f"{other.get('version'):<{MAX_WV}}")
@@ -136,7 +142,7 @@ def print_version_check(
     # local ver
     print(f"{f'Local Version':{MAX_WV}}", end="")
     # registry ver
-    print(f"{f'DockerHub Version':{MAX_WV}}", end="")
+    print(f"{f'Registry Version':{MAX_WV}}", end="")
     # origin ver
     print(f"{f'Origin Version':{MAX_WV}}", end="")
     # origin provider
@@ -399,6 +405,12 @@ def create_list_argparse(subparsers: argparse._SubParsersAction, ):
         help="List all versions of the tools.",
     )
     version_exclusive_group = version_parser.add_mutually_exclusive_group()
+    version_exclusive_group.add_argument(
+        "-s",
+        "--silent",
+        action="store_true",
+        help="Updates database without listing and gives some stats.",
+    )
     version_exclusive_group.add_argument(
         "-n", "--name", help="Check single tool by the name.",
     )
@@ -420,19 +432,29 @@ def create_list_argparse(subparsers: argparse._SubParsersAction, ):
 
 
 def list_handler(args):
+    loglevel = args.log_level if args.log_level else ("WARNING" if args.quiet else "INFO")
+
     if (args.list_sub_command or args.sub_command == "versions") and (
             args.all or args.tag != DEFAULT_IMAGE_FILTER_TAG or args.size
     ):
         logging.getLogger(__name__).warning(
             "No effect with size or tag related arguments when used with 'versions' subcommand"
         )
-
+    # Change logging format in silent mode, needs reloading on < 3.8. Python 3.8 would have 'force' parameter
+    if hasattr(args, "silent") and args.silent:
+        reload(logging)
+        date_strftime_format = "%Y-%m-%d %H:%M:%S"
+        logging.basicConfig(
+            format=f"{' ':<{PRE_SPACE}}%(asctime)s %(levelname)s - %(name)s: %(message)s",
+            datefmt=date_strftime_format,
+            level=getattr(logging, loglevel),
+        )
     # If exported as module and parent parser of 'list' not defining
     if not hasattr(args, "tools"):
         args.tools = ""
     if not hasattr(args, "registry"):
         args.registry = None
-    reg = ToolRegistry(args.config, args.tools, default_remote=args.registry)
+    reg = ToolRegistry(args.config, args.tools, default_remote=args.registry, silent=args.silent if hasattr(args, "silent") else False)
 
     if not args.list_sub_command:
 
@@ -470,6 +492,8 @@ def list_handler(args):
                     tools, location, prefix=reg.remote_registry.full_prefix,
                     filter_by=(args.tag if not args.all else ""), show_size=args.size
                 )
+            else:
+                print("No single tool available for given arguments.")
 
         else:
             tool_list = reg.get_tools(defined_tag=args.tag if not args.all else "")
@@ -496,6 +520,15 @@ def list_handler(args):
                 force_refresh=args.force_refresh,
             )
         )
+        if args.silent and ret:
+            # On silent mode, use logger instead of printing, mainly used for database updating
+            logger = logging.getLogger("main")
+            logger.info("Database updated.")
+            logger.info(f"Total amount of tools: {len([k for k in ret.keys()])}")
+            logger.info(f"Total amount available updates for remote tools: "
+                        f"{len([k for k in ret.keys() if ret.get(k).get('updates').get('remote')])}")
+            loop.close()
+            sys.exit(0)
         if args.name and not args.json:
             print_single_tool_version_check(ret, args.with_tags)
         elif not args.name and not args.json:
