@@ -1,11 +1,11 @@
-from requests import Response
-from cincanregistry.remotes import DockerHubRegistry, QuayRegistry
-from cincanregistry._registry import RegistryBase
-from .metafiles import MetaHandler
-from typing import Union
-from abc import ABCMeta, abstractmethod
-import pathlib
 import logging
+import pathlib
+from abc import ABCMeta, abstractmethod
+
+from requests import Response
+
+from cincanregistry.remotes import DockerHubRegistry, QuayRegistry
+from cincanregistry.utils import read_index_file
 
 
 class ReadmeHandler(metaclass=ABCMeta):
@@ -19,10 +19,11 @@ class ReadmeHandler(metaclass=ABCMeta):
         if not self.tools_repo_path:
             raise RuntimeError("'Tools' repository path must be defined.'")
         self.index_path = self.tools_repo_path / self.config.index_file
-        self.tool_locations = MetaHandler(self.config).read_index_file(self.index_path)
         # Some numbers
         self.max_size: int = 100000
         self.max_description_size: int = 200
+        # Set available tools
+        self.tool_locations = read_index_file(self.index_path)
 
     def update_readme_all_tools(self, ):
         """
@@ -160,4 +161,3 @@ class QuayReadmeHandler(QuayRegistry, ReadmeHandler):
         }
         resp = self.session.put(repository_uri, json=data)
         return resp
-
