@@ -1,23 +1,19 @@
 import pytest
-import pathlib
-from cincanregistry import HubReadmeHandler
-from unittest.mock import mock_open
 
 
+@pytest.mark.skip(reason="Work in progress")
 def test_create_hub_readme_handler(mocker):
-
     paths = ["stable", "development", "unmaintained"]
-    mocker.patch("cincanregistry.metafiles.MetaHandler.read_index_file", return_value=paths)
     # reg = HubReadmeHandler("/")
     # assert reg.max_size == 25000
     # assert reg.max_description_size == 100
 
 
+@pytest.mark.skip(reason="Work in progress")
 def test_update_tool_readme(mocker, tmpdir):
     paths = ["stable", "development", "unmaintained"]
-    mocker.patch("cincanregistry.metafiles.MetaHandler.read_index_file", return_value=paths)
-    p = tmpdir.mkdir("my_tool").join("README.md")
-    p.write("# This is useful example tool.")
+    # p = tmpdir.mkdir("my_tool").join("README.md")
+    # p.write("# This is useful example tool.")
     # reg = HubReadmeHandler("/")
     # mocker.patch.object(
     #     reg.client, "ping", return_value=True, autospec=True,
